@@ -565,9 +565,16 @@ departments = {
             "San Bernardo del Viento":{"dane_code":"23675"},
         }
     },
+    "bogotá, d.c.":{
+        "dane_code":"11",
+        "municipalities":{
+            "Bogotá":{"dane_code":"11001"},
+        }
+    },¶ 
     "Cundinamarca":{
         "dane_code":"25",
         "municipalities":{
+            "Bogotá":{"dane_code":"11001"},
             "Albán":{"dane_code":"25019"},
             "Anolaima":{"dane_code":"25040"},
             "Chía":{"dane_code":"25175"},
@@ -1166,4 +1173,4 @@ departments = {
             "Cumaribo":{"dane_code":"99773"},
         }
     }
-}
+}
\ No newline at end of file
